@@ -4,7 +4,7 @@ Main interface for waf service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_waf import (
         Client,
         GetRateBasedRuleManagedKeysPaginator,
@@ -26,10 +26,8 @@ Usage::
         WAFClient,
     )
 
-    session = boto3.Session()
-
-    client: WAFClient = boto3.client("waf")
-    session_client: WAFClient = session.client("waf")
+    session = Session()
+    client: WAFClient = session.client("waf")
 
     get_rate_based_rule_managed_keys_paginator: GetRateBasedRuleManagedKeysPaginator = client.get_paginator("get_rate_based_rule_managed_keys")
     list_activated_rules_in_rule_group_paginator: ListActivatedRulesInRuleGroupPaginator = client.get_paginator("list_activated_rules_in_rule_group")
@@ -49,8 +47,8 @@ Usage::
     list_xss_match_sets_paginator: ListXssMatchSetsPaginator = client.get_paginator("list_xss_match_sets")
     ```
 """
-from mypy_boto3_waf.client import WAFClient
-from mypy_boto3_waf.paginator import (
+from .client import WAFClient
+from .paginator import (
     GetRateBasedRuleManagedKeysPaginator,
     ListActivatedRulesInRuleGroupPaginator,
     ListByteMatchSetsPaginator,
